# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/faqs/litecm/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Faqs\\Litecm\\": "packages/faqs/litecm/src",
            "Faqs\\Litecm\\Seeders\\": "packages/faqs/litecm/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Faqs\Litecm\Providers\LitecmServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Litecm'  => Faqs\Litecm\Facades\Litecm::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Faqs\\Litecm\\Seeders\\LitecmTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Faqs\Litecm\Providers\LitecmServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Faqs\Litecm\Providers\LitecmServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Faqs\Litecm\Providers\LitecmServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/litecm/{modulename}

**User**

    http://path-to-route-folder/user/litecm/{modulename}

**Public**

    http://path-to-route-folder/litecms


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/litecm/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/litecm/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/litecm/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/litecm/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/litecm/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/litecm/{modulename}/{slug}
    METHOD: GET